# Histogramming and plotting examples

In this directory you will find a set of examples to perform
basic 2D/3D plotting and histogramming.

Run any of the examples from command line with:

`vedo -ir example.py`
